=======
History
=======

0.3.0 (2021-05-04)
------------------

* Add indegrees attribute in Position and Constraints class for angle units.
* Add asdegrees, asradians methods for converting Position and Constraints
attributes between degrees and radians.
* Add asdegrees parameter to get_position and get_virtal_angles methods for
returning calculated angles in degrees or radians.
* Add fields attribute to Position class with angle names.
* Remove TORAD, TODEG constants.
* Change the default angles units in Position class to degrees.
* Fix manually set UB matrix type compatibility issue.

0.2.1 (2021-04-20)
------------------

* Fix reported miscut parameters to exclude azimuthal component.

0.2.0 (2021-04-14)
------------------

* Add support for Python version >= 3.6.

0.1.1 (2021-04-06)
------------------

* Add versions for package dependencies.

0.1.0 (2021-04-06)
------------------

* First release on PyPI.
